<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>mainwindow</name>
    <message>
        <source>CSSU Tuner</source>
        <translation>CSSU Tuner</translation>
    </message>
    <message>
        <source>Transitions lenght (ms)</source>
        <translation>Animaation kesto (ms)</translation>
    </message>
    <message>
        <source>Status menu rows</source>
        <translation>Tilavalikon näkyvät
rivit</translation>
    </message>
    <message>
        <source>Status menu rows
(portait)</source>
        <translation>Tilavalikon näkyvät
rivit (pystymoodi)</translation>
    </message>
    <message>
        <source>Always show FM-applet</source>
        <translation>Näytä aina FM-appletti</translation>
    </message>
    <message>
        <source>App menu editing Enabled</source>
        <translation>Ohj. valikko muokattavissa</translation>
    </message>
    <message>
        <source>Homescreen editing Enabled</source>
        <translation>Työpöytä muokattavissa</translation>
    </message>
    <message>
        <source>Ultra fast Transitions</source>
        <translation>Ultra-nopeat animaatiot</translation>
    </message>
    <message>
        <source>Fast Transitions</source>
        <translation>Nopeat animaatiot</translation>
    </message>
    <message>
        <source>Normal Transitions</source>
        <translation>Normaalit animaatiot</translation>
    </message>
    <message>
        <source>Slow Transitions</source>
        <translation>Hitaat animaatiot</translation>
    </message>
    <message>
        <source>Turtle Transitions</source>
        <translation>Kilpikonna-animaatiot</translation>
    </message>
    <message>
        <source>Default style Task Switcher</source>
        <translation>Oletusnäkymä avoimissa sovelluksissa</translation>
    </message>
    <message>
        <source>Single column Task Switcher</source>
        <translation>Yhden sarakkeen näkymä</translation>
    </message>
    <message>
        <source>Double columns Task Switcher</source>
        <translation>Kahden sarakkeen näkymä</translation>
    </message>
    <message>
        <source>App menu blur</source>
        <translation>Ohjelmavalikon pehmeys</translation>
    </message>
    <message>
        <source>App menu scroll speed</source>
        <translation>Ohj. val. rullausnopeus</translation>
    </message>
    <message>
        <source>Parallax</source>
        <translation>Työpöydän vieritystaso</translation>
    </message>
    <message>
        <source>Blurless saturation Enabled</source>
        <translation>Mustavalkoinen valikkoefekti</translation>
    </message>
    <message>
        <source>Force rotation Enabled</source>
        <translation>Pakota kääntötoiminnot</translation>
    </message>
    <message>
        <source>Rotate around z-axis Enabled</source>
        <translation>Käännä Z-akeselin ympäri</translation>
    </message>
    <message>
        <source>Tactile feedback Enabled</source>
        <translation>Tactile -toiminnot päällä</translation>
    </message>
    <message>
        <source>Zoom on press Enabled</source>
        <translation>Zoomaa painettaessa</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Author: d-iivil&lt;br /&gt;Licence: GPL</source>
        <translation>Tekijä: d-iivil - Lisenssi: GPL</translation>
    </message>
    <message>
        <source>version</source>
        <translation>versio</translation>
    </message>
    <message>
        <source>Transitions updated!</source>
        <translation>Animaatiot päivitetty!</translation>
    </message>
    <message>
        <source>Reboot is required to activate all changes.</source>
        <translation>Uudelleenkäynnistys tarvitaan jotta kaikki muutokset tulevat näkyviksi.</translation>
    </message>
</context>
</TS>
